# 009

|                              | airCondDumpHisense   |
|:-----------------------------|:---------------------|
| bindTime                     | 1715959596828        |
| createTime                   | 0                    |
| deviceFeatureCode            | 104                  |
| deviceFeatureName            | 104冷暖节能无功率           |
| deviceId                     | <redacted>           |
| deviceNickName               | Klimatyzator         |
| deviceTypeCode               | 009                  |
| deviceTypeName               |                      |
| offlineState                 | 1                    |
| puid                         | <redacted>           |
| role                         | 1                    |
| roomId                       | 4349167              |
| roomName                     | Living Room          |
| seq                          | 0                    |
| statusList.daily_energy_kwh  | 0                    |
| statusList.f-filter          | 0                    |
| statusList.f_e_arkgrille     | 0                    |
| statusList.f_e_dwmachine     | 0                    |
| statusList.f_e_incoiltemp    | 0                    |
| statusList.f_e_incom         | 0                    |
| statusList.f_e_indisplay     | 0                    |
| statusList.f_e_ineeprom      | 0                    |
| statusList.f_e_inele         | 0                    |
| statusList.f_e_infanmotor    | 0                    |
| statusList.f_e_inhumidity    | 0                    |
| statusList.f_e_inkeys        | 0                    |
| statusList.f_e_intemp        | 0                    |
| statusList.f_e_invzero       | 0                    |
| statusList.f_e_inwifi        | 0                    |
| statusList.f_e_outcoiltemp   | 0                    |
| statusList.f_e_outeeprom     | 0                    |
| statusList.f_e_outgastemp    | 0                    |
| statusList.f_e_outtemp       | 0                    |
| statusList.f_e_over_cold     | 0                    |
| statusList.f_e_over_hot      | 0                    |
| statusList.f_e_push          | 0                    |
| statusList.f_e_upmachine     | 0                    |
| statusList.f_e_waterfull     | 0                    |
| statusList.f_electricity     | 0                    |
| statusList.f_humidity        | 128                  |
| statusList.f_temp_in         | 26                   |
| statusList.f_votage          | 228                  |
| statusList.t_dal             | 1                    |
| statusList.t_demand_response | 0                    |
| statusList.t_eco             | 0                    |
| statusList.t_fan_mute        | 0                    |
| statusList.t_fan_speed       | 0                    |
| statusList.t_fan_speed_s     | 0                    |
| statusList.t_fanspeedcv      | 0                    |
| statusList.t_power           | 1                    |
| statusList.t_sleep           | 0                    |
| statusList.t_super           | 0                    |
| statusList.t_swing_angle     | 0                    |
| statusList.t_swing_direction | 5                    |
| statusList.t_swing_follow    | 3                    |
| statusList.t_talr            | 1                    |
| statusList.t_temp            | 23                   |
| statusList.t_temp_compensate | 7                    |
| statusList.t_temp_type       | 0                    |
| statusList.t_tms             | 1                    |
| statusList.t_up_down         | 0                    |
| statusList.t_work_mode       | 2                    |
| useTime                      | 1715959596807        |
| wifiId                       | <redacted>           |

## Generated from

- [`airCondDumpHisense.json`](airCondDumpHisense.json)
